import type { Metadata } from "next";
import { Inter } from "next/font/google";
import "./globals.css";
import Navbar from "@/components/layout/Navbar";
import Image from 'next/image';

const inter = Inter({ subsets: ["latin"] });

export const metadata: Metadata = {
  title: "帷幄君成 - 数字员工平台",
  description: "智能物流解决方案",
};

export default function RootLayout({
  children,
}: {
  children: React.ReactNode;
}) {
  return (
    <html lang="zh">
      <body className={inter.className}>
        <Navbar />
        <main className="min-h-screen bg-gradient-to-b from-[var(--ai-surface)] to-white pt-16">
          {children}
        </main>
        <footer className="bg-gradient-to-br from-[var(--ai-primary)] to-[var(--ai-dark)] text-white py-10">
          <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
            <div className="mb-8 flex justify-center flex-col items-center">
              <div className="relative w-16 h-16 mb-3">
                <Image 
                  src="/images/logo.jpg" 
                  alt="帷幄君成Logo" 
                  width={64}
                  height={64}
                  className="object-contain"
                  priority
                />
              </div>
              <div className="text-xl font-bold">帷幄君成</div>
              <div className="text-sm text-gray-300 mt-1">智能物流解决方案</div>
            </div>
            <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
              <div>
                <h3 className="text-lg font-semibold mb-4 text-[#F5A800]">关于我们</h3>
                <ul className="space-y-2">
                  <li className="hover:text-[#F5A800] transition-colors cursor-pointer">公司介绍</li>
                  <li className="hover:text-[#F5A800] transition-colors cursor-pointer">联系方式</li>
                  <li className="hover:text-[#F5A800] transition-colors cursor-pointer">加入我们</li>
                </ul>
              </div>
              <div>
                <h3 className="text-lg font-semibold mb-4 text-[#F5A800]">产品服务</h3>
                <ul className="space-y-2">
                  <li className="hover:text-[#F5A800] transition-colors cursor-pointer">数字员工</li>
                  <li className="hover:text-[#F5A800] transition-colors cursor-pointer">智能客服</li>
                  <li className="hover:text-[#F5A800] transition-colors cursor-pointer">物流解决方案</li>
                </ul>
              </div>
              <div>
                <h3 className="text-lg font-semibold mb-4 text-[#F5A800]">帮助中心</h3>
                <ul className="space-y-2">
                  <li className="hover:text-[#F5A800] transition-colors cursor-pointer">使用指南</li>
                  <li className="hover:text-[#F5A800] transition-colors cursor-pointer">常见问题</li>
                  <li className="hover:text-[#F5A800] transition-colors cursor-pointer">技术支持</li>
                </ul>
              </div>
            </div>
            <div className="mt-8 pt-8 border-t border-opacity-20 border-[#F5A800] text-center">
              <div className="flex items-center justify-center mb-4">
                <span className="inline-block w-2 h-2 bg-[#00A0E9] rounded-full mr-2 animate-pulse"></span>
                <span className="inline-block w-2 h-2 bg-[#5D54A4] rounded-full mx-2 animate-pulse delay-300"></span>
                <span className="inline-block w-2 h-2 bg-[#F5A800] rounded-full ml-2 animate-pulse delay-500"></span>
              </div>
              <p>© 2024 帷幄君成. All rights reserved.</p>
            </div>
          </div>
        </footer>
      </body>
    </html>
  );
}
